@@ -140,7 +140,7 @@ class Shell:
         b.append("  scrapy     scrapy module (contains scrapy.Request, scrapy.Selector, etc)")
         for k, v in sorted(self.vars.items()):
             if self._is_relevant(v):
-                b.append("  %-10s %s" % (k, v))
+                b.append(f"  {k:<10} {v}")
         b.append("Useful shortcuts:")
         if self.inthread:
             b.append("  fetch(url[, redirect=True]) "
@@ -150,7 +150,7 @@ class Shell:
         b.append("  shelp()           Shell help (print this help)")
         b.append("  view(response)    View response in a browser")
 
-        return "\n".join("[s] %s" % line for line in b)
+        return "\n".join(f"[s] {line}" for line in b)
 
     def _is_relevant(self, value):
         return isinstance(value, self.relevant_classes) or is_item(value)
