@@ -16,7 +16,7 @@ class SignalManager:
         section.
 
         :param receiver: the function to be connected
-        :type receiver: callable
+        :type receiver: collections.abc.Callable
 
         :param signal: the signal to connect to
         :type signal: object
