@@ -21,8 +21,8 @@ class Root(Resource):
         for nl in nlist:
             args['n'] = nl
             argstr = urlencode(args, doseq=True)
-            request.write("<a href='/follow?{0}'>follow {1}</a><br>"
-                          .format(argstr, nl).encode('utf8'))
+            request.write(f"<a href='/follow?{argstr}'>follow {nl}</a><br>"
+                          .encode('utf8'))
         request.write(b"</body></html>")
         return b''
 
@@ -39,6 +39,6 @@ if __name__ == '__main__':
 
     def _print_listening():
         httpHost = httpPort.getHost()
-        print("Bench server at http://{}:{}".format(httpHost.host, httpHost.port))
+        print(f"Bench server at http://{httpHost.host}:{httpHost.port}")
     reactor.callWhenRunning(_print_listening)
     reactor.run()
