@@ -8,9 +8,8 @@ from scrapy.exceptions import ScrapyDeprecationWarning
 def attribute(obj, oldattr, newattr, version='0.12'):
     cname = obj.__class__.__name__
     warnings.warn(
-        "%s.%s attribute is deprecated and will be no longer supported "
-        "in Scrapy %s, use %s.%s attribute instead"
-        % (cname, oldattr, version, cname, newattr),
+        f"{cname}.{oldattr} attribute is deprecated and will be no longer supported "
+        f"in Scrapy {version}, use {cname}.{newattr} attribute instead",
         ScrapyDeprecationWarning,
         stacklevel=3)
 
@@ -57,7 +56,7 @@ def create_deprecated_class(
         warned_on_subclass = False
 
         def __new__(metacls, name, bases, clsdict_):
-            cls = super(DeprecatedClass, metacls).__new__(metacls, name, bases, clsdict_)
+            cls = super().__new__(metacls, name, bases, clsdict_)
             if metacls.deprecated_class is None:
                 metacls.deprecated_class = cls
             return cls
@@ -73,7 +72,7 @@ def create_deprecated_class(
                 if warn_once:
                     msg += ' (warning only on first subclass, there may be others)'
                 warnings.warn(msg, warn_category, stacklevel=2)
-            super(DeprecatedClass, cls).__init__(name, bases, clsdict_)
+            super().__init__(name, bases, clsdict_)
 
         # see https://www.python.org/dev/peps/pep-3119/#overloading-isinstance-and-issubclass
         # and https://docs.python.org/reference/datamodel.html#customizing-instance-and-subclass-checks
@@ -88,7 +87,7 @@ def create_deprecated_class(
                 # is the deprecated class itself - subclasses of the
                 # deprecated class should not use custom `__subclasscheck__`
                 # method.
-                return super(DeprecatedClass, cls).__subclasscheck__(sub)
+                return super().__subclasscheck__(sub)
 
             if not inspect.isclass(sub):
                 raise TypeError("issubclass() arg 1 must be a class")
@@ -102,7 +101,7 @@ def create_deprecated_class(
                 msg = instance_warn_message.format(cls=_clspath(cls, old_class_path),
                                                    new=_clspath(new_class, new_class_path))
                 warnings.warn(msg, warn_category, stacklevel=2)
-            return super(DeprecatedClass, cls).__call__(*args, **kwargs)
+            return super().__call__(*args, **kwargs)
 
     deprecated_cls = DeprecatedClass(name, (new_class,), clsdict or {})
 
@@ -116,7 +115,7 @@ def create_deprecated_class(
         # deprecated class is in jinja2 template). __module__ attribute is not
         # important enough to raise an exception as users may be unable
         # to fix inspect.stack() errors.
-        warnings.warn("Error detecting parent module: %r" % e)
+        warnings.warn(f"Error detecting parent module: {e!r}")
 
     return deprecated_cls
 
@@ -124,7 +123,7 @@ def create_deprecated_class(
 def _clspath(cls, forced=None):
     if forced is not None:
         return forced
-    return '{}.{}'.format(cls.__module__, cls.__name__)
+    return f'{cls.__module__}.{cls.__name__}'
 
 
 DEPRECATION_RULES = [
@@ -135,9 +134,9 @@ DEPRECATION_RULES = [
 def update_classpath(path):
     """Update a deprecated path from an object with its new location"""
     for prefix, replacement in DEPRECATION_RULES:
-        if path.startswith(prefix):
+        if isinstance(path, str) and path.startswith(prefix):
             new_path = path.replace(prefix, replacement, 1)
-            warnings.warn("`{}` class is deprecated, use `{}` instead".format(path, new_path),
+            warnings.warn(f"`{path}` class is deprecated, use `{new_path}` instead",
                           ScrapyDeprecationWarning)
             return new_path
     return path
